/***************************************************************************
                          rxpmsim.h  -  description
                             -------------------
    begin                : Mon Sep 27 1999
    copyright            : (C) 1999 by Andreas Mustun
    email                : andrew@ribbonsoft.com
 ***************************************************************************/

#ifndef RXPMSIM_H
#define RXPMSIM_H

#include "xpm/simstart.xpm"
#include "xpm/simsmooth.xpm"
//#include "xpm/simpointing.xpm"

#include "xpm/info.xpm"
//#include "xpm/edit.xpm"
//#include "xpm/layerlist.xpm"

#include "xpm/simbroken.xpm"
#include "xpm/simrapidmove.xpm"
#include "xpm/simdetails.xpm"
//#include "xpm/simgrid.xpm"

#endif


